Plotting
========

* Intuitive plotting routines with ``matplotlib`` similar syntax (see :ref:`plotting_ref`)
* Plotting tools built for interactivity in Jupyter notebooks (see :ref:`ipy_tools_ref`)

.. toctree::
   :maxdepth: 2

   plotting
   ipy_tools
   qt_plotting
   widgets
